#ifndef NT2_INCLUDE_FUNCTIONS_REALPOW_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_REALPOW_HPP_INCLUDED

#include <nt2/exponential/include/functions/realpow.hpp>

#endif
